# Introduction
Continuous improvement requires measurement to asses how your process is working and whether it improves as you make adjustments over time.

The **One Door Metrics Helper** is a tool designed to simplify collecting periodic software metrics from JIRA. Previously collecting such metrics was tedious requiring you to:

- Navigate to a JIRA search page.
- Lookup or compose an appropriate JQL query.
- Copy and paste into the search field.
- Determine the sprint start and end dates.
- Edit the search string to use the corresponding dates.
- Run the query.
- Optionally download the results as a CSV file and open in Excel.

The **One Door Metrics Helper** can automate each of these steps.

![](main_window.png)  
## Engineering Metrics

To use the tool, you would normally specify a *Sprint End Date* and *Duration* at the upper left of the Input section.  Then select the query you want to run from the PopUp menu at right.  Observe that the query string has been composed for you in the output section below including the specified range of dates. You can use the double arrow buttons to move forward or backward between sprints. Notice the dates in the query string are updated automatically.

You can us the Copy button to manually copy the query string. When you select a new query or move forward or backward between sprints, the query string is copied automatically and ready to be pasted into the search field directly.

Instead of copying and pasting the query string into a browser window, you can press the **JIRA Search** button to open a dedicated Web View that runs the search automatically.  For metrics that require downloading the search results for further computation in Excel, you can press the **Download CSV** button to run the search, automatically download as CSV, and then open in Excel.


## Individual Developer Metrics
As a technical project manager, you may want to know how many stories were assigned to each developer or how many story points were completed over the course of a project. Select the **Individual** tab at the upper right to access these metrics.  To cover an entire project period, you can specify a project start date at the lower left of the input section.  

![](individual_metrics.png)  

When the *JIRA Username* field is empty, the tool will query for the currently logged in JIRA user. To select a different user, you can use the small PopUp at right to choose the desired user by name and the tool will fill in their JIRA username for you.  The names in the PopUp menu are grouped by organizational unit and similar job roles.

## Modifying or Extending Query Definitions or Users
If you wish to modify a query string or add another user, press the *Show Templates File* button at the lower right. This will open a window in the Finder to show the files containing the query string definitions so you can edit them directly. The definition files are in Property List (.plist) format which is standard for Macintosh applications. Plists are similar to JSON, but use a more human readable XML format (or alternate compact format).  If you double click on one of the plist files, it will open in a Plist or plain text editor..

## Mean Time To Respond (MTTR) Metrics
Getting accurate MTTR metrics in JIRA has been challenging because the "Resolved" date when a ticket is actually closed bears little resemblance to the response time. Instead we use when the ticket became "Ready to Deploy", "Verify In Production", or Closed. To make the calculated response time more accurate, you can set the *Sprint Duration* to 1 Day. 

![](mttr_window.png)  
To make it easier to check each day to see when individual tickets were finished, you can use the *Skip None Found* check box.  If you then press *Download CSV*, the tool will start from the Sprint End Date and step backward day-by-day until it finds one or more tickets that were completed on that day and open the downloaded CSV file in Excel.  

One of the columns in the spreadsheet will show the *Created* date.  You can copy and paste the content of the *Calculate Response Time* field to the cell immediately after the Created column in row 2.  This will subtract the Created date from from the completed date to calculate the response time in days.

If there is more than one ticket listed, you can *Fill Down* in Excel to repeat the calculation for additional rows. A convenient short cut is press and hold the shift key while you press the down-arrow key to extend the selection.  Then use Control-D to fill down.

If there is only one ticket completed during a week for example, the tool will step through the week and show it to you in Excel.  If there are multiple tickets completed during a week, you will need to accumulate these and average their response times.

# Appendix

## About the One Door Metrics Helper
The **One Door Metrics Helper** is a Macintosh native application developed in Cocoa/Obj-C using Apple's Xcode.  Apple's WebKit is used to open a dedicated Web View and run JavaScript on the DOM.

You can download the latest version of the tool from here:  
http://sustworks.com/download/One%20Door%20Metrics%20Helper.app.zip

The git repository can be found here:  
https://github.com/psichel/onedoor_metrics_helper

The tool is code signed with an appropriate Apple Developer ID so it can be launched without complaining it is from an unknown developer.

## Engineering Metrics

MTTR Priority >= Urgent  
MTTR Priority High  
MTTR Severity >= Serious  
MTTR Severity Major  

Project Bugs Added  
Project Bugs Closed  
Project Bugs Finished  

Stories Added  
Story Points Closed  
Story Points Finished  

Support Bugs Added  
Support Bugs Closed  
Support Issues Added  
Support Production Defects  

## Individual Metrics

Project Bugs Assigned  
Project Bugs Rejected  
Project Tickets Created  

Stories Assigned  
Stories Rejected  

Support Bugs Assigned  

## [End]


